summaryrefslogtreecommitdiff
path: root/src/mongo/db/auth/authorization_manager.h
diff options
context:
space:
mode:
authorAndreas Nilsson <andreas.nilsson@10gen.com>2014-09-12 11:29:50 -0400
committerAndreas Nilsson <andreas.nilsson@10gen.com>2014-09-17 15:44:49 -0700
commitdedf038860746ad0bed3a6f37ae702587933b5f8 (patch)
tree4c7939436e56c4953ae71d55ccd4d887015cf9d6 /src/mongo/db/auth/authorization_manager.h
parent859876746f3abcf7a97e150e1179cc70325ea274 (diff)
downloadmongo-dedf038860746ad0bed3a6f37ae702587933b5f8.tar.gz
SERVER-15179 Auth upgrade from MONGODB-CR -> SCRAM-SHA-1
Diffstat (limited to 'src/mongo/db/auth/authorization_manager.h')
-rw-r--r--src/mongo/db/auth/authorization_manager.h11
1 files changed, 9 insertions, 2 deletions
diff --git a/src/mongo/db/auth/authorization_manager.h b/src/mongo/db/auth/authorization_manager.h
index b45712847d0..600a2ef032a 100644
--- a/src/mongo/db/auth/authorization_manager.h
+++ b/src/mongo/db/auth/authorization_manager.h
@@ -121,11 +121,18 @@ namespace mongo {
static const int schemaVersion26Upgrade = 2;
/**
* Auth schema version for MongoDB 2.6. Users are stored in admin.system.users,
* roles in admin.system.roles.
*/
static const int schemaVersion26Final = 3;
+ /**
+ * Auth schema version for MongoDB 2.8 SCRAM only mode.
+ * Users are stored in admin.system.users, roles in admin.system.roles.
+ * MONGODB-CR credentials have been replaced with SCRAM credentials in the user documents.
+ */
+ static const int schemaVersion28SCRAM = 4;
+
// TODO: Make the following functions no longer static.
/**
@@ -121,11 +121,18 @@ namespace mongo {
static const int schemaVersion26Upgrade = 2;
/**
- * Auth schema version for MongoDB 2.6. Users are stored in admin.system.users,
- * roles in admin.system.roles.
+ * Auth schema version for MongoDB 2.6 and 2.8 MONGODB-CR/SCRAM mixed auth mode.
+ * Users are stored in admin.system.users, roles in admin.system.roles.
*/
static const int schemaVersion26Final = 3;